==> jc-1.4.0.tar.gz: gnu/java/net/URLParseError.h <==
// public class gnu.java.net.URLParseError

// class file dependencies
// @dep_class 879151611398f9c9 gnu_java_net_URLParseError
// @dep_class 308333d803f5ab9f java_lang_Error
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_lang_Error

#include "java/lang/Error.h"

#ifndef _JC_gnu_java_net_URLParseError_H_
#define _JC_gnu_java_net_URLParseError_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_net_URLParseError$sub_refs	_jc_gnu_java_net_URLParseError$sub_refs;
typedef struct _jc_gnu_java_net_URLParseError$sub_nonrefs	_jc_gnu_java_net_URLParseError$sub_nonrefs;
typedef struct _jc_gnu_java_net_URLParseError$refs	_jc_gnu_java_net_URLParseError$refs;
typedef struct _jc_gnu_java_net_URLParseError$nonrefs	_jc_gnu_java_net_URLParseError$nonrefs;
typedef struct _jc_gnu_java_net_URLParseError$object	_jc_gnu_java_net_URLParseError$object;

typedef const struct _jc_gnu_java_net_URLParseError$vmethods	_jc_gnu_java_net_URLParseError$vmethods;
typedef const struct _jc_gnu_java_net_URLParseError$vtable	_jc_gnu_java_net_URLParseError$vtable;
typedef const struct _jc_gnu_java_net_URLParseError$vtype	_jc_gnu_java_net_URLParseError$vtype;

// Constructors
extern void _jc_gnu_java_net_URLParseError$method$_init$c31b894660454d13(_jc_env *, struct _jc_gnu_java_net_URLParseError$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_gnu_java_net_URLParseError$vmethods {
};

// Vtable
struct _jc_gnu_java_net_URLParseError$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Error$vmethods	java_lang_Error;
	_jc_gnu_java_net_URLParseError$vmethods	gnu_java_net_URLParseError;
};

// Vtype
struct _jc_gnu_java_net_URLParseError$vtype {
	_jc_type			type;
	_jc_gnu_java_net_URLParseError$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_URLParseError$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_net_URLParseError$refs {
    _jc_gnu_java_net_URLParseError$sub_refs	gnu_java_net_URLParseError;
    _jc_java_lang_Error$sub_refs	java_lang_Error;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_URLParseError$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_URLParseError$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Error$sub_nonrefs	java_lang_Error;
    _jc_gnu_java_net_URLParseError$sub_nonrefs	gnu_java_net_URLParseError;
};

// Object instance structure
struct _jc_gnu_java_net_URLParseError$object {
	_jc_gnu_java_net_URLParseError$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_URLParseError$vtype	*vtype;
	_jc_gnu_java_net_URLParseError$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_URLParseError$vtype _jc_gnu_java_net_URLParseError$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_URLParseError, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_URLParseError$class_object;

#endif	/* _JC_gnu_java_net_URLParseError_H_ */

==> jc-1.4.6.tar.gz: gnu/java/net/URLParseError.h <==
// public class gnu.java.net.URLParseError

// class file dependencies
// @dep_class 879151611398f9c9 gnu_java_net_URLParseError
// @dep_class 308333d803f5ab9f java_lang_Error
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_lang_Error

#include "java/lang/Error.h"

#ifndef _JC_gnu_java_net_URLParseError_H_
#define _JC_gnu_java_net_URLParseError_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_net_URLParseError$sub_refs	_jc_gnu_java_net_URLParseError$sub_refs;
typedef struct _jc_gnu_java_net_URLParseError$sub_nonrefs	_jc_gnu_java_net_URLParseError$sub_nonrefs;
typedef struct _jc_gnu_java_net_URLParseError$refs	_jc_gnu_java_net_URLParseError$refs;
typedef struct _jc_gnu_java_net_URLParseError$nonrefs	_jc_gnu_java_net_URLParseError$nonrefs;
typedef struct _jc_gnu_java_net_URLParseError$object	_jc_gnu_java_net_URLParseError$object;

typedef const struct _jc_gnu_java_net_URLParseError$vmethods	_jc_gnu_java_net_URLParseError$vmethods;
typedef const struct _jc_gnu_java_net_URLParseError$vtable	_jc_gnu_java_net_URLParseError$vtable;
typedef const struct _jc_gnu_java_net_URLParseError$vtype	_jc_gnu_java_net_URLParseError$vtype;

// Constructors
extern void _jc_gnu_java_net_URLParseError$method$_init$c31b894660454d13(_jc_env *, struct _jc_gnu_java_net_URLParseError$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_net_URLParseError$vmethods {
};

// Vtable
struct _jc_gnu_java_net_URLParseError$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Error$vmethods	java_lang_Error;
	_jc_gnu_java_net_URLParseError$vmethods	gnu_java_net_URLParseError;
};

// Vtype
struct _jc_gnu_java_net_URLParseError$vtype {
	_jc_type			type;
	_jc_gnu_java_net_URLParseError$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_URLParseError$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_net_URLParseError$refs {
    _jc_gnu_java_net_URLParseError$sub_refs	gnu_java_net_URLParseError;
    _jc_java_lang_Error$sub_refs	java_lang_Error;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_URLParseError$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_URLParseError$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Error$sub_nonrefs	java_lang_Error;
    _jc_gnu_java_net_URLParseError$sub_nonrefs	gnu_java_net_URLParseError;
};

// Object instance structure
struct _jc_gnu_java_net_URLParseError$object {
	_jc_gnu_java_net_URLParseError$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_URLParseError$vtype	*vtype;
	_jc_gnu_java_net_URLParseError$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_URLParseError$vtype _jc_gnu_java_net_URLParseError$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_URLParseError, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_URLParseError$class_object;

#endif	/* _JC_gnu_java_net_URLParseError_H_ */
